#
# Cookbook Name:: IHS
# Recipe:: default
#
# Copyright 2016, rohit company
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#include_recipe 'InstallationManager'


IHSbinary_dir = "#{Chef::Config[:file_cache_path]}/IHSbinaries"
binaries = [ "#{node['IHS']['package-name-1']}", "#{node['IHS']['package-name-2']}", "#{node['IHS']['package-name-3']}"]
checksums = [ "#{node['IHS']['package1-sha256sum']}", "#{node['IHS']['package2-sha256sum']}", "#{node['IHS']['package3-sha256sum']}"]

IHS_dir = "#{node['IHS']['IHS_install_dir']}"
im_dir = "#{node['IHS']['imcl_install_dir']}"
imagentdata_dir = "#{node['IHS']['imagentdata_install_dir']}"
imshared_dir = "#{node['IHS']['imshared_install_dir']}"
ihsuserhome = "#{node['IHS']['IHSuserhome']}"

directory ihsuserhome do
  owner 'root'
  group 'root'
  mode '0755'
  action :create
end

directory IHSbinary_dir do
  owner 'root'
  group 'root'
  mode '0755'
  action :create
end

directory 'IHS_dir' do
  owner 'root'
  group 'root'
  mode '0755'
  action :create
end

Chef::Log.info("Creating OS group ihsgrp: #{node['IHS']['IHS85-group']} ")
group "#{node['IHS']['IHS85-group']}" do
action :create
end

Chef::Log.info("Creating OS user ihsuser and adding to ihsgrp")
user "#{node['IHS']['IHS85-user']}" do
  group "#{node['IHS']['IHS85-group']}"
  home "#{node['IHS']['IHSuserhome']}"
  action :create
end

count = 0

binaries.each { | package_name |
	 execute 'copy-IHS' do
    action :run
      command "scp #{node['IHS']['ftploginuser']}@#{node['IHS']['binaryhost']}:#{node['IHS']['ftppath']}/#{package_name} #{IHSbinary_dir}"
    cwd IHSbinary_dir
  end
  ruby_block "Validate Package Checksum" do
    action :run
    block do
      require 'digest'
      checksum = Digest::SHA256.file("#{IHSbinary_dir}/#{package_name}").hexdigest
      if checksum != checksums[count]
        raise "#{package_name} #{count} Downloaded package Checksum #{checksum} does not match known checksum #{checksums[count]}"
      #else
        #count += 1
      end
      count += 1
    end
  end

	execute 'extract-IHS' do
		action :run
      command "unzip -o #{package_name}"
	  	cwd IHSbinary_dir
	end
  #raise "count after extract = #{count}"
}

template "#{IHSbinary_dir}/#{node['IHS']['IHS-responsefile']}" do
  source 'IHS-responsefile.erb'
  variables(
  IHSid: "#{node['IHS']['IHS85-packageid']}",
  IHSdesc: "#{node['IHS']['IHS85-profiledesc']}",
  IHSfeatures: "#{node['IHS']['IHS85-features']}",
  IHSpath: "#{node['IHS']['IHS85-installpath']}",
  imsharedpath: "#{node['IHS']['imshared_install_dir']}",
  IHSbinarypath: "#{IHSbinary_dir}"
  )
  owner 'root'
  group 'root'
  mode '0644'
  notifies :run, 'execute[install-IHS85]', :immediately
end

execute 'install-IHS85' do
  command "#{node['IHS']['imcl-path']} -acceptLicense -showProgress input '#{IHSbinary_dir}/#{node['IHS']['IHS-responsefile']}' -dataLocation '#{node['IHS']['imagentdata_install_dir']}' -log '#{IHSbinary_dir}/IHS85NDinstall.log'"
  cwd IHSbinary_dir
  action :run
end

template "#{node['IHS']['IHS85-httpdconf']}" do
  source 'httpd-conf.erb'
  owner 'root'
  group 'root'
  mode '0644'
end

Chef::Log.info("Modifying directory permissions to 755")
execute 'recursivedir-permissions' do
  command "chown -R #{node['IHS']['IHS85-user']}:#{node['IHS']['IHS85-group']} #{node['IHS']['IHS85-installpath']}"
  action :run
end

Chef::Log.info("Modifying directory permissions to 755")
execute 'recursivedir-permissions' do
  command "find #{node['IHS']['IHS85-installpath']} -type d -exec chmod 755 {} \\;"
  action :run
end

Chef::Log.info("Modifying file permissions to 754")
execute 'recursivefile-permissions' do
  command "find #{node['IHS']['IHS85-installpath']} -type f -exec chmod 754 {} \\;"
  action :run
end

execute 'start-IHS85' do
  command "#{node['IHS']['IHS85-binpath']}/apachectl -k start"
  cwd IHSbinary_dir
  action :run
end

# directory IHSbinary_dir do
#   action :delete
#   recursive true
# end
